@@ -1,7 +1,7 @@
 package Bencher::Scenario::RandomLineModules;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -77,11 +77,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::RandomLineModules
+Bencher::Scenario::RandomLineModules - Benchmark modules which pick random line(s) from a file
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::RandomLineModules (from Perl distribution Bencher-Scenario-RandomLineModules), released on 2016-01-05.
+This document describes version 0.03 of Bencher::Scenario::RandomLineModules (from Perl distribution Bencher-Scenario-RandomLineModules), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -97,6 +97,8 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 BENCHMARKED MODULES
 
+Version numbers shown below are the versions used when running the sample benchmark.
+
 L<File::Random::Pick> 0.02
 
 L<File::RandomLine> 0.20
@@ -121,33 +123,43 @@ Code template:
 
 
 
+=back
+
+=head1 BENCHMARK DATASETS
+
+=over
+
+=item * 1k_line
+
+=item * 10k_line
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m RandomLineModules >>):
 
- +-----+----------------------------------------------------------------------+----------+----------+---------+---------+
- | seq | name                                                                 | rate     | time     | errors  | samples |
- +-----+----------------------------------------------------------------------+----------+----------+---------+---------+
- | 1   | {dataset=>"10k_line",participant=>"File::Random::Pick::random_line"} | 435      | 2.3ms    | 9.1e-07 | 20      |
- | 0   | {dataset=>"1k_line",participant=>"File::Random::Pick::random_line"}  | 4.03e+03 | 0.248ms  | 6.9e-07 | 20      |
- | 3   | {dataset=>"10k_line",participant=>"File::RandomLine"}                | 6.1e+04  | 0.016ms  | 5.6e-08 | 23      |
- | 2   | {dataset=>"1k_line",participant=>"File::RandomLine"}                 | 6.11e+04 | 0.0164ms | 6.7e-09 | 20      |
- +-----+----------------------------------------------------------------------+----------+----------+---------+---------+
+ +---------------------------------+----------+-----------+-----------+------------+---------+---------+
+ | participant                     | dataset  | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +---------------------------------+----------+-----------+-----------+------------+---------+---------+
+ | File::Random::Pick::random_line | 10k_line |       591 |   1.69    |       1    | 2.7e-07 |      20 |
+ | File::Random::Pick::random_line | 1k_line  |      5720 |   0.175   |       9.67 | 5.3e-08 |      20 |
+ | File::RandomLine                | 1k_line  |    135000 |   0.00742 |     228    | 3.3e-09 |      20 |
+ | File::RandomLine                | 10k_line |    140000 |   0.0073  |     230    |   1e-08 |      20 |
+ +---------------------------------+----------+-----------+-----------+------------+---------+---------+
 
 
-Benchmark module startup overhead:
+Benchmark module startup overhead (C<< bencher -m RandomLineModules --module-startup >>):
 
- +-----+---------------------+--------+-------------------+---------+---------+
- | seq | name                | time   | mod_overhead_time | errors  | samples |
- +-----+---------------------+--------+-------------------+---------+---------+
- | 2   | File::RandomLine    | 13.8ms | 9.06ms            | 2.4e-05 | 20      |
- | 1   | File::Random::Pick  | 8.2ms  | 3.4ms             | 8.2e-05 | 20      |
- | 0   | perl -e1 (baseline) | 4.8ms  | 0ms               | 5.3e-05 | 20      |
- +-----+---------------------+--------+-------------------+---------+---------+
+ +---------------------+-----------+------------------------+------------+---------+---------+
+ | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+-----------+------------------------+------------+---------+---------+
+ | File::RandomLine    |       9   |                    6.4 |        1   |   3e-05 |      20 |
+ | File::Random::Pick  |       4.6 |                    2   |        2   | 1.6e-05 |      20 |
+ | perl -e1 (baseline) |       2.6 |                    0   |        3.5 | 1.2e-05 |      20 |
+ +---------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
